==> piwigo_2.0.10.orig.tar.gz: piwigo-2.0.10/plugins/LocalFilesEditor/language/es_ES/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configuración local';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Idiomas';
$lang['locfiledit_onglet_plug'] = 'Plugin personal';
$lang['locfiledit_cant_save'] = 'Imposible escribir el fichero. Verifique los permisos (chmod) del expediente "include/".';
$lang['locfiledit_newfile'] = 'El fichero no existe y será creado en el momento del registro por LocalFiles Editor';
$lang['locfiledit_save_config'] = 'El fichero ha sido registrado.';
$lang['locfiledit_show_default'] = 'Fijar el fichero ';
$lang['locfiledit_save_bak'] = 'Una copia de salvaguardia del fichero será creada en el momento del registro';
$lang['locfiledit_saved_bak'] = 'Una copia de salvaguardia ha sido creada (%s)';
$lang['locfiledit_save_file'] = 'Registrar el fichero';
$lang['locfiledit_choose_file'] = 'Escoja un fichero que hay que editar';
$lang['locfiledit_edit'] = 'Editar';
$lang['locfiledit_restore'] = 'Cargar el fichero de salvaguardia';
$lang['locfiledit_restore_confirm'] = '¿ Desea cargar el fichero de salvaguardia?
Usted deberá luego hacer clic Registrar para restaurarlo.';
$lang['locfiledit_bak_loaded1'] = 'Fichero cargado de salvaguardia';
$lang['locfiledit_bak_loaded2'] = 'Usted debe registrarlo para salvaguardarlo.';
$lang['locfiledit_syntax_error'] = '¡ Error de sintaxis! Imposible registrar el fichero.';
$lang['locfiledit_enable_editarea'] = 'Acelerar Editarea';
$lang['locfiledit_disable_editarea'] = 'Desactivar Editarea ';
$lang['locfiledit_new_tpl'] = 'Crear un nuevo fichero ';
$lang['locfiledit_new_filename'] = 'Nombre del fichero ';
$lang['locfiledit_model'] = 'Modelo ';
$lang['locfiledit_empty_page'] = 'Página virgen';
$lang['locfiledit_parent_directory'] = 'Expediente allegado';
$lang['locfiledit_filename_error'] = 'Carácteres prohibidos en el nombre del fichero.';
$lang['locfiledit_file_already_exists'] = 'El fichero ya existe.';
$lang['locfiledit_model_error'] = 'Por favor, seleccione un modelo.';
$lang['locfiledit_empty_filename'] = 'Por favor, indique un nombre de fichero.';

?>

==> piwigo_2.1.2.orig.tar.gz: piwigo-2.1.2/plugins/LocalFilesEditor/language/es_ES/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configuración local';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Idiomas';
$lang['locfiledit_onglet_plug'] = 'Plugin personal';
$lang['locfiledit_cant_save'] = 'Imposible escribir el fichero. Verifique los permisos (chmod) del expediente "include/".';
$lang['locfiledit_newfile'] = 'El fichero no existe y será creado en el momento del registro por LocalFiles Editor';
$lang['locfiledit_save_config'] = 'El fichero ha sido registrado.';
$lang['locfiledit_show_default'] = 'Fijar el fichero ';
$lang['locfiledit_save_bak'] = 'Una copia de salvaguardia del fichero será creada en el momento del registro';
$lang['locfiledit_saved_bak'] = 'Una copia de salvaguardia ha sido creada (%s)';
$lang['locfiledit_save_file'] = 'Registrar el fichero';
$lang['locfiledit_choose_file'] = 'Escoja un fichero que hay que editar';
$lang['locfiledit_edit'] = 'Editar';
$lang['locfiledit_restore'] = 'Cargar el fichero de salvaguardia';
$lang['locfiledit_restore_confirm'] = '¿ Desea cargar el fichero de salvaguardia?
Usted deberá luego hacer clic Registrar para restaurarlo.';
$lang['locfiledit_bak_loaded1'] = 'Fichero cargado de salvaguardia';
$lang['locfiledit_bak_loaded2'] = 'Usted debe registrarlo para salvaguardarlo.';
$lang['locfiledit_syntax_error'] = '¡ Error de sintaxis! Imposible registrar el fichero.';
$lang['locfiledit_enable_editarea'] = 'Acelerar Editarea';
$lang['locfiledit_disable_editarea'] = 'Desactivar Editarea ';
$lang['locfiledit_new_tpl'] = 'Crear un nuevo fichero ';
$lang['locfiledit_new_filename'] = 'Nombre del fichero ';
$lang['locfiledit_model'] = 'Modelo ';
$lang['locfiledit_empty_page'] = 'Página virgen';
$lang['locfiledit_parent_directory'] = 'Expediente allegado';
$lang['locfiledit_filename_error'] = 'Carácteres prohibidos en el nombre del fichero.';
$lang['locfiledit_file_already_exists'] = 'El fichero ya existe.';
$lang['locfiledit_model_error'] = 'Por favor, seleccione un modelo.';
/* TODO */ $lang['locfiledit_empty_filename'] = 'Por favor, indique un nombre de fichero.';
/* TODO */ $lang['locfiledit_webmaster_only'] = 'Only webmasters can create or modify local files.';

?>
